@@ -4,7 +4,7 @@
 #' @param to_qtr (date in quarters) the date to be inflated to, where nominal price = real price. Must be of the form "YYYY-Qq" e.g. "1066-Q2".
 #' @param adjustment Should there be an adjustment made to the index? Adjustments include 'none' (no adjustment), 'seasonal', or 'trimmed' [referring to trimmed mean]. By default, \code{seasonal}.
 #' @param useABSConnection Should the function connect with ABS.Stat via an SDMX connection? By default set to \code{FALSE} in which case a pre-prepared index table is used. This is much faster and more reliable (in terms of errors), though of course relies on the package maintainer to keep the tables up-to-date.
-#' The internal data was updated on 2019-03-23 to 2018-Q4.
+#' The internal data was updated on 2019-05-02 to 2019-Q1.
 #' If using \code{useABSConnection = TRUE}, ensure you have \code{rsdmx (>= 0.5-10)} up-to-date.
 #' @return A vector of real prices.
 #' @export
@@ -37,9 +37,19 @@ cpi_inflator_quarters <- function(from_nominal_price,
                "seasonal" = cpi.url.seasonal.adjustment, 
                "trimmed" = cpi.url.trimmed.mean)
       
-      cpi <- rsdmx::readSDMX(url)
-      message("Using ABS sdmx connection")
-      setDT(as.data.frame(cpi))
+      cpi <- tryCatch({
+        rsdmx::readSDMX(url)
+        message("Using ABS sdmx connection")
+        setDT(as.data.frame(cpi))
+      }, 
+      error = function(e) {
+        message("SDMX failed with error ", e$m,
+                "falling back to useABSConnection = FALSE.")
+        switch(adjustment, 
+               "none" = cpi_unadj, 
+               "seasonal" = cpi_seasonal_adjustment, 
+               "trimmed" = cpi_trimmed)
+      })
     } else {
       switch(adjustment, 
              "none" = cpi_unadj, 
