@@ -1,9 +1,10 @@
 #' Install 'taxstats' files
 #' @description The taxstats packages provide the sample files as released by the ATO. These packages are used for testing, but are not available through CRAN as they are too large.
+#' @param pkg The package to install such as \code{"taxstats"} or \code{"taxstats1516"}.
 #' @param ... Arguments passed to \code{\link[utils]{install.packages}}.
 #' @export
 
-install_taxstats <- function(...) {
+install_taxstats <- function(pkg = c("taxstats"), ...) {
   if (!missing(..1)) {
     dots <- list(...)
     if ("lib" %in% names(dots)) {
@@ -12,7 +13,7 @@ install_taxstats <- function(...) {
       }
     }
   }
-  utils::install.packages(c("taxstats"),
+  utils::install.packages(pkgs = c(pkg),
                           repos = "https://hughparsonage.github.io/tax-drat",
                           type = "source", 
                           ...)
